@@ -1,7 +1,5 @@
 use std::sync::atomic::AtomicI32;
-
-use chrono::{Local, Timelike};
-use crossbeam_channel::{Receiver, SendError, RecvError};
+use may::sync::mpsc::{Receiver, Sender};
 use log::{Level, Metadata, Record};
 use parking_lot::RwLock;
 
@@ -16,6 +14,8 @@ use crate::wait::FastLogWaitGroup;
 use std::result::Result::Ok;
 use std::time::{SystemTime, Duration};
 use std::sync::Arc;
+use std::sync::mpsc::SendError;
+use may::go;
 
 lazy_static! {
     static ref LOG_SENDER: RwLock<Option<LoggerSender>> = RwLock::new(Option::None);
@@ -23,12 +23,12 @@ lazy_static! {
 
 pub struct LoggerSender {
     pub filter: Box<dyn Filter>,
-    pub inner: crossbeam_channel::Sender<FastLogRecord>,
+    pub inner: Sender<FastLogRecord>,
 }
 
 impl LoggerSender {
-    pub fn new(cap: usize, filter: Box<dyn Filter>) -> (Self, Receiver<FastLogRecord>) {
-        let (s, r) = crossbeam_channel::bounded(cap);
+    pub fn new( filter: Box<dyn Filter>) -> (Self, Receiver<FastLogRecord>) {
+        let (s, r) = may::sync::mpsc::channel();
         (Self { inner: s, filter }, r)
     }
     pub fn send(&self, data: FastLogRecord) -> Result<(), SendError<FastLogRecord>> {
@@ -36,10 +36,10 @@ impl LoggerSender {
     }
 }
 
-fn set_log(cup: usize, level: log::Level, filter: Box<dyn Filter>) -> Receiver<FastLogRecord> {
+fn set_log( level: log::Level, filter: Box<dyn Filter>) -> Receiver<FastLogRecord> {
     LOGGER.set_level(level);
     let mut w = LOG_SENDER.write();
-    let (log, recv) = LoggerSender::new(cup, filter);
+    let (log, recv) = LoggerSender::new(filter);
     *w = Some(log);
     return recv;
 }
@@ -71,23 +71,21 @@ impl log::Log for Logger {
         metadata.level() <= self.get_level()
     }
     fn log(&self, record: &Record) {
-        if self.enabled(record.metadata()) {
-            //send
-            if let Some(sender) = LOG_SENDER.read().as_ref() {
-                if !sender.filter.filter(record) {
-                    let fast_log_record = FastLogRecord {
-                        command: Command::CommandRecord,
-                        level: record.level(),
-                        target: record.metadata().target().to_string(),
-                        args: record.args().to_string(),
-                        module_path: record.module_path().unwrap_or_default().to_string(),
-                        file: record.file().unwrap_or_default().to_string(),
-                        line: record.line().clone(),
-                        now: SystemTime::now(),
-                        formated: String::new(),
-                    };
-                    sender.send(fast_log_record);
-                }
+        //send
+        if let Some(sender) = LOG_SENDER.read().as_ref() {
+            if !sender.filter.filter(record) {
+                let fast_log_record = FastLogRecord {
+                    command: Command::CommandRecord,
+                    level: record.level(),
+                    target: record.metadata().target().to_string(),
+                    args: record.args().to_string(),
+                    module_path: record.module_path().unwrap_or_default().to_string(),
+                    file: record.file().unwrap_or_default().to_string(),
+                    line: record.line().clone(),
+                    now: SystemTime::now(),
+                    formated: String::new(),
+                };
+                sender.send(fast_log_record);
             }
         }
     }
@@ -103,7 +101,6 @@ static LOGGER: Logger = Logger {
 /// channel_cup: example -> 1000
 pub fn init_log(
     log_file_path: &str,
-    channel_cup: usize,
     level: log::Level,
     mut filter: Option<Box<dyn Filter>>,
     debug_mode: bool,
@@ -116,30 +113,22 @@ pub fn init_log(
     if filter.is_some() {
         log_filter = filter.take().unwrap();
     }
-
-    let utc = chrono::Utc::now();
-    let tz = chrono::Local::now();
     return init_custom_log(
         appenders,
-        channel_cup,
         level,
         log_filter,
-        Box::new(FastLogFormatRecord {
-            hour: tz.hour() - utc.hour()
-        }),
+        Box::new(FastLogFormatRecord::new()),
     );
 }
 
 /// initializes the log file path
 /// log_dir_path:  example->  "log/"
-/// channel_log_cup: example -> 1000
 /// max_temp_size: do zip if temp log full
 /// allow_zip_compress: zip compress log file
 /// filter: log filter
 /// packer: you can use ZipPacker or LZ4Packer or custom your Packer
 pub fn init_split_log(
     log_dir_path: &str,
-    channel_log_cup: usize,
     max_temp_size: LogSize,
     rolling_type: RollingType,
     level: log::Level,
@@ -161,22 +150,16 @@ pub fn init_split_log(
     if filter.is_some() {
         log_filter = filter.take().unwrap();
     }
-    let utc = chrono::Utc::now();
-    let tz = chrono::Local::now();
     return init_custom_log(
         appenders,
-        channel_log_cup,
         level,
         log_filter,
-        Box::new(FastLogFormatRecord {
-            hour: tz.hour() - utc.hour()
-        }),
+        Box::new(FastLogFormatRecord::new()),
     );
 }
 
 pub fn init_custom_log(
     appenders: Vec<Box<dyn LogAppender>>,
-    log_cup: usize,
     level: log::Level,
     filter: Box<dyn Filter>,
     format: Box<dyn RecordFormat>,
@@ -185,12 +168,11 @@ pub fn init_custom_log(
         return Err(LogError::from("[fast_log] appenders can not be empty!"));
     }
     let wait_group = FastLogWaitGroup::new();
-    let main_recv = set_log(log_cup, level, filter);
-
-    let (back_sender, back_recv) = crossbeam_channel::bounded(log_cup * 10 * appenders.len());
+    let main_recv = set_log(level, filter);
+    let (back_sender, back_recv) =  may::sync::mpsc::channel();
     //main recv data
     let wait_group_main = wait_group.clone();
-    std::thread::spawn(move || {
+    go!(move ||{
         loop {
             let data = main_recv.recv();
             if data.is_ok() {
@@ -204,7 +186,6 @@ pub fn init_custom_log(
             }
         }
     });
-
     let wait_group_back = wait_group.clone();
     //back recv data
     std::thread::spawn(move || {
@@ -258,3 +239,30 @@ pub fn exit() -> Result<(), LogError> {
 
     return Err(LogError::E("[fast_log] exit fail!".to_string()));
 }
+
+
+pub fn flush() -> Result<(), LogError> {
+    let sender = LOG_SENDER.read();
+    if sender.is_some() {
+        let sender = sender.as_ref().unwrap();
+        let fast_log_record = FastLogRecord {
+            command: Command::CommandFlush,
+            level: log::Level::Info,
+            target: String::new(),
+            args: "flush".to_string(),
+            module_path: String::new(),
+            file: String::new(),
+            line: None,
+            now: SystemTime::now(),
+            formated: "flush".to_string(),
+        };
+        let result = sender.send(fast_log_record);
+        match result {
+            Ok(()) => {
+                return Ok(());
+            }
+            _ => {}
+        }
+    }
+    return Err(LogError::E("[fast_log] flush fail!".to_string()));
+}
